/*
Written by Mark Hodgetts & Shaun Simpson 11-07-2017 Copyright Cambridge Research Systems Ltd.

libLiveTrack library specific definitions.
*/
#ifndef LIBLIVETRACK_H__
#define LIBLIVETRACK_H__

#define LIBARY_VERSION 44

/* ABI (application binary interface) version is used for binary interface compatibility testing.
 * The MSB indicates the level of compatibility. If this number differs then the 
 * current library ABI is incompatible with this header file. 
 *
 * The ABI LSB is used to track changes that do not break compatibility such as the 
 * addition of new functions.
 */
#define LIBARY_ABI_VERSION 0x0801

#ifndef __BORLANDC__
  #include <stdint.h>
#else
  typedef unsigned long int uint32_t;
  typedef long int int32_t;
  typedef unsigned char uint8_t;
  typedef unsigned short uint16_t;
  typedef uint16_t uintptr_t;
  #if __BORLANDC__ <= 0x0520
    /* Treat an unsigned 64 bit variable as two usigned 32 bit variables stored in an array. */
    typedef uint32_t uint64_t[2];
  #else
    typedef unsigned long long int uint64_t[2];
  #endif
#endif

/* Include stdbool.h if bool is undefined. */
#ifndef bool
#include <stdbool.h>
#endif

enum LIVETRACK_EYE {
	LEFT_EYE,
	RIGHT_EYE
};

enum LIVETRACK_MODEL {
	LIVETRACK_NONE,
	LIVETRACK_FM,
	LIVETRACK_AP,
	LIVETRACK_AV,
	LIVETRACK_PRESTO,
	LIVETRACK_MODLE_UNKNOWN = 100,
};

enum LIVETRACK_RESULTS_TYPE {
	LIVETRACK_RESULTS_RAW,
	LIVETRACK_RESULTS_CALIBRATED,
	LIVETRACK_RESULTS_RAW_8192,
	LIVETRACK_RESULTS_CALIBRATED_8192
};

enum LIVETRACK_PARAMETER {
	LIVETRACK_TRACKING,		// CT_FOCUS_ABSOLUTE_CONTROL - used to control which eye is tracked
	LIVETRACK_IPD,			// CT_ZOOM_ABSOLUTE_CONTROL - used to control which debug images are presented
	LIVETRACK_SCROLL,		// CT_PANTILT_ABSOLUTE_CONTROL - Controls the camera scroll
	LIVETRACK_OVERLAY,		// PU_BACKLIGHT_COMPENSATION_CONTROL - Used to switch tracking overlays on/off
	LIVETRACK_BRIGHTNESS,	// CAMERA_Brightness
	LIVETRACK_CONTRAST,		// CAMERA_Contrast
	LIVETRACK_DIAGNOSTIC,	// PU_GAIN_CONTROL   - Used to switch the diagnostic traces on or off
	LIVETRACK_SRG			// Sets ETP.SRGthreshold
};

enum LIVETRACK_TRACKING_MODE {
	LIVETRACK_TRACKING_MONOCULAR,
	LIVETRACK_TRACKING_BINOCULAR,
};

enum LIVETRACK_RESET_FRAMECOUNT {
	RFC_OFF,
	RFC_FRAME,
	RFC_TRIGGER
};

enum LIVETRACK_ERROR {
	LIVETRACK_ERROR_OK = 0,
	LIVETRACK_ERROR_HID = -1,
	LIVETRACK_ERROR_TIMEOUT = -2,
	LIVETRACK_ERROR_PARAM = -3,
	LIVETRACK_ERROR_NOT_SUPPORTED = -4,
	LIVETRACK_ERROR_FILE_WRITE = -5,
	LIVETRACK_ERROR_FILE_READ = -6,
	LIVETRACK_ERROR_FILE_VERSION = -7,
	LIVETRACK_ERROR_FILE_CORRUPT = -8,
	LIVETRACK_ERROR_FILE_BAD_HEADER = -9,
	LIVETRACK_ERROR_INTERNAL = -10,
	LIVETRACK_ERROR_GSTREAMER_BUS = -11,
	LIVETRACK_ERROR_GSTREAMER_INIT = -12,
	LIVETRACK_ERROR_GSTREAMER_LINK = -13,
	LIVETRACK_ERROR_GSTREAMER_START = -14,
	LIVETRACK_ERROR_NO_RESULT = -15,
	LIVETRACK_ERROR_CALIBRATION_VERIFICATION = -16,
	LIVETRACK_ERROR_NOT_CONNECTED = -100,
	LIVETRACK_ERROR_UNKNOWN = -1000,
};

enum LIVETRACK_PIN_FUNCTION  {
	PIN_FUNCTION_NULL,
	PIN_FUNCTION_DIN,
	PIN_FUNCTION_LEFT_TRACKED,
	PIN_FUNCTION_RIGHT_TRACKED,
	PIN_FUNCTION_BLINK,
	PIN_FUNCTION_LEFT_ROI,
	PIN_FUNCTION_RIGHT_ROI,
	PIN_FUNCTION_LEFT_FIXATION,
	PIN_FUNCTION_RIGHT_FIXATION,
	PIN_FUNCTION_FRAMECOUNT0,
	PIN_FUNCTION_FRAMECOUNT1,
	PIN_FUNCTION_FRAMECOUNT2,
	PIN_FUNCTION_FRAMECOUNT3,
	PIN_FUNCTION_FRAMECOUNT4,
	PIN_FUNCTION_FRAMECOUNT5,
	PIN_FUNCTION_FRAMECOUNT6,
	PIN_FUNCTION_FRAMECOUNT7,
	PIN_FUNCTION_FRAMECOUNT8,
	PIN_FUNCTION_FRAMECOUNT9,
	PIN_FUNCTION_FRAMECOUNT10,
	PIN_FUNCTION_FRAMECOUNT11,
	PIN_FUNCTION_FRAMECOUNT12,
	PIN_FUNCTION_FRAMECOUNT13,
	PIN_FUNCTION_FRAMECOUNT14,
	PIN_FUNCTION_FRAMECOUNT15,
	PIN_FUNCTION_FRAMECOUNT16,
	PIN_FUNCTION_FRAMECOUNT17,
	PIN_FUNCTION_FRAMECOUNT18,
	PIN_FUNCTION_FRAMECOUNT19,
	PIN_FUNCTION_FRAMECOUNT20,
	PIN_FUNCTION_FRAMECOUNT21,
	PIN_FUNCTION_FRAMECOUNT22,
	PIN_FUNCTION_FRAMECOUNT23,
	PIN_FUNCTION_FRAMECOUNT24,
	PIN_FUNCTION_FRAMECOUNT25,
	PIN_FUNCTION_FRAMECOUNT26,
	PIN_FUNCTION_FRAMECOUNT27,
	PIN_FUNCTION_FRAMECOUNT28,
	PIN_FUNCTION_FRAMECOUNT29,
	PIN_FUNCTION_FRAMECOUNT30,
	PIN_FUNCTION_FRAMECOUNT31
};

enum LIVETRACK_ANALOGUE_FUNCTION {
	APIN_FUNCTION_NULL,
	APIN_FUNCTION_LEFT_X_MM,
	APIN_FUNCTION_LEFT_Y_MM,
	APIN_FUNCTION_LEFT_Z_MM,
	APIN_FUNCTION_LEFT_DIA_MM,
	APIN_FUNCTION_RIGHT_X_MM,
	APIN_FUNCTION_RIGHT_Y_MM,
	APIN_FUNCTION_RIGHT_Z_MM,
	APIN_FUNCTION_RIGHT_DIA_MM,
	APIN_FUNCTION_LEFT_AZIMUTH,
	APIN_FUNCTION_LEFT_ELEVATION,
	APIN_FUNCTION_RIGHT_AZIMUTH,
	APIN_FUNCTION_RIGHT_ELEVATION,
	APIN_FUNCTION_LEFT_LATTITUDE,
	APIN_FUNCTION_LEFT_LONGITUDE,
	APIN_FUNCTION_RIGHT_LATTITUDE,
	APIN_FUNCTION_RIGHT_LONGITUDE,
	APIN_FUNCTION_LEFT_PUPIL_X_PIX,
	APIN_FUNCTION_LEFT_PUPIL_Y_PIX,
	APIN_FUNCTION_LEFT_GLINT_X_PIX,
	APIN_FUNCTION_LEFT_GLINT_Y_PIX,
	APIN_FUNCTION_RIGHT_PUPIL_X_PIX,
	APIN_FUNCTION_RIGHT_PUPIL_Y_PIX,
	APIN_FUNCTION_RIGHT_GLINT_X_PIX,
	APIN_FUNCTION_RIGHT_GLINT_Y_PIX,
	APIN_FUNCTION_TIMECODE
};

typedef enum {
	PIN_DEFAULT_HOLD,
	PIN_DEFAULT_0,
	PIN_DEFAULT_1
} PinDefault;

#pragma pack(push, 1)

typedef struct {
	// Bitfield indicating which RIOs are active (1 = active).
	uint32_t ActiveROIs;	

	// Camera pixel locations and sizes.
	float GlintX, GlintY;
	float PupilX, PupilY;
	float PupilMajorAxis, PupilMinorAxis;

	// Raw left and right distance between pupil and glint centres in camera pixels.
	float VectX, VectY;

	// Calibrated gaze in various different coordinate systems.
	float GazeX, GazeY, GazeZ;
	float GazeAzimuth, GazeElevation;
	float GazeLongitude, GazeLatitude;

	bool Tracked;
	bool Enabled;
	bool Calibrated;
	bool Dropped;

	// Indicates the first active ROI.
	uint8_t ROI;
} T_EYE_DATA;

typedef struct T_RESULTS_STRUCT {
	uint16_t Size;
	uint64_t Timestamp;
	uint16_t ResultsType;
	T_EYE_DATA Eye[2];
	uint32_t DigitalIO;
	uint8_t FixationDetected;
}T_RESULTS_STRUCT;

typedef struct targ_struct {
	double Target_X;
	double Target_Y;
	double Vector_X;
	double Vector_Y;
}targ_struct;

/* Header "LiveTrackCAL"
 * CRC is calculated using CRC32 on the entire file contents, excepting the CRC32 field.
 * POLYNOMIAL		0x04C11DB7
 * INITIAL_VALUE		0xFFFFFFFF
 * FINAL_XOR_VALUE	0xFFFFFFFF
 * REVERSED_DATA		TRUE
 * REVERSED_OUT		FALSE */
typedef struct {
	uint32_t Size;
	char Header[16];
	uint8_t Version;
	bool Calibrated[2];
	double Cal[2][16];
	double RPC;
	double ViewingDistance;
	double PixelsPerMM;
	double xGlintMedian[2];
	double yGlintMedian[2];
	uint32_t CRC32;
} T_CALIBRATION_FILE;

typedef struct
{
	uint8_t Function;    	// see LIVETRACK_PIN_FUNCTION
	uint8_t Default;		// see PinDefault
	double TopLeftX;     	// of ROI in mm
	double TopLeftY;     	// of ROI in mm
	double BottomRightX; 	// of ROI in mm
	double BottomRightY; 	// of ROI in mm
	uint32_t Duration;    	// fixation minimum duration in ms
	double Range; 			// fixation maximum range in mm
} T_IO_PIN_CONFIGURATION;

typedef struct
{
	uint8_t Function;    // see LIVETRACK_ANALOGUE_FUNCTION
	uint8_t DefaultEnable; // '1' enables DefaultValue as an output, '0' makes data 'hold' - if missing frames
	double DefaultValue;
	double Gain;
	double Offset;
} T_IO_ANALOGUE_CONFIGURATION;

#pragma pack(pop)

#ifdef __cplusplus
extern "C" {
#endif

	uint32_t crsLiveTrackGetLibVersion(void);
	uint32_t crsLiveTrackGetAbiVersion(void);

	int32_t crsLiveTrackHidInit(void);
	int32_t crsLiveTrackHidClose(void);
	int32_t crsLiveTrackGetResult(T_RESULTS_STRUCT* results);
	int32_t crsLiveTrackGetLastResult(T_RESULTS_STRUCT* results);
	int32_t crsLiveTrackFlushResults(void);

	int32_t crsLiveTrackSetPupilCalibration(double diameter, double pixels);
	int32_t crsLiveTrackGetPupilCalibration(double *pixelsToMM);
	int32_t crsLiveTrackGetTrackingMode(int32_t *mode);
	int32_t crsLiveTrackSetTrackingMode(int32_t mode);
	int32_t crsLiveTrackCalibrate(uint32_t numberOfPoints, targ_struct a[], double cal[], double rpc, double viewDist);
	int32_t crsLiveTrackSetCalibration(int32_t eye, double cal[], double rpc, double viewDist, double xGlintMedian, double yGlintMedian);
	int32_t crsLiveTrackGetCalibration(int32_t eye, double cal[], double *rpc, double *viewDist, double *xGlintMedian, double *yGlintMedian);
	int32_t crsLiveTrackSetResultsType(int32_t type);
	int32_t crsLiveTrackCalibrateDevice(int32_t eye, uint32_t numberOfPoints, targ_struct a[], double rpc, double viewDist, double xGlintMedian, double yGlintMedian, int32_t *calErr);
	int32_t crsLiveTrackArmTimestamp(int32_t param);
	
	int32_t crsLiveTrackSetParam(int32_t param, int32_t value);
	int32_t crsLiveTrackSetTracking(bool leftEye, bool rightEye);
	int32_t crsLiveTrackGetParam(int32_t param, int32_t *value);
	int32_t crsLiveTrackGetTracking(bool *leftEye, bool *rightEye);
	int32_t crsLiveTrackGetSerialNumber(char *serialNumber, size_t maxLength);
	int32_t crsLiveTrackGetFirmwareVersion(uint16_t *version);
	int32_t crsLiveTrackGetFirmwareBuildDateTime(char *dateTime, size_t maxLength);

	int32_t crsLiveTrackSetIPV4Config(uint8_t manual, uint32_t address, uint32_t mask, uint32_t gateway, uint32_t dns1, uint32_t dns2);
	int32_t crsLiveTrackGetIPV4Config(uint8_t *manual, uint32_t *address, uint32_t *mask, uint32_t *gateway, uint32_t *dns1, uint32_t *dns2);
	int32_t crsLiveTrackGetEthMacAddress(char *mac, char *address, size_t maxLength);
	int32_t crsLiveTrackSaveCapturedImages(void);

	int32_t crsLiveTrackGetPinFunctions(uint8_t *pinFunctions, size_t size, uint32_t *pinCount);
	int32_t crsLiveTrackGetPinFunction(uint8_t pin, T_IO_PIN_CONFIGURATION *config);
	int32_t crsLiveTrackGetAnalogueFunction(uint8_t channel, T_IO_ANALOGUE_CONFIGURATION *config);
	int32_t crsLiveTrackSetPinFunction(uint8_t pin, T_IO_PIN_CONFIGURATION *config);
	int32_t crsLiveTrackSetAnalogueFunction(uint8_t channel, T_IO_ANALOGUE_CONFIGURATION *config);

	int32_t crsLiveTrackInit(void);
	int32_t crsLiveTrackClose(void);

	/* Start saving results.
	 * Returns 0 on success. */
	int32_t crsLiveTrackStartTracking(void);

	/* Stop saving results. 
	 * Returns 0 on success. */
	int32_t crsLiveTrackStopTracking(void);

	/* Returns the current buffer position. */
	int32_t crsLiveTrackGetBufferPosition(void);

	/* Sets the buffer position.
	* Returns 0 on success else returns error (-1) if position is invalid. */
	int32_t crsLiveTrackSetBufferPosition(int32_t index);

	/* Returns the result at the current position.
	 * Returns 0 on success else error (-1) if no result is returned. */
	int32_t crsLiveTrackGetBufferedResult(T_RESULTS_STRUCT* result, bool removeFromBuffer);

	/* Returns the number of results that have been buffered.
	 * Returns the number of buffered results. */
	int32_t crsLiveTrackGetResultsCount(void);

	/* Removes all buffered results.
	 * Returns 0 */
	int32_t crsLiveTrackClearDataBuffer(void);

	int32_t crsLiveTrackSaveCalibration(char *filename);
	int32_t crsLiveTrackLoadCalibration(char *filename);

	/* Returns the device calibration state.
	 * Returns 0 on success. */
	int32_t crsLiveTrackGetCalibrated(int32_t eye, bool *calibrated);

	/* Returns the device pupil calibration state.
	* Returns 0 on success. */
	int32_t crsLiveTrackGetPupilCalibrated(bool *calibrated);

	/* Returns true if tracking data is being saved into the buffer. */
	bool crsLiveTrackGetTrackingStarted(void);

	/* Gets the configured capture parameters. 
	 * Returns 0 on success.
	 * Note: rate: Configured capture rate in frames per second. 
	 * All other units are in pixels. */
	int32_t crsLiveTrackGetCaptureConfig(uint32_t *width, uint32_t *height, uint32_t *rate, uint32_t *offsetX, uint32_t *offsetY);

#ifdef __cplusplus
}
#endif

#endif
