function [isCalibrated, ErrorCode] = crsLiveTrackGetCalibrated(whichEye)
% CRSLIVETRACKGETCALIBRATED determines whether the toolbox has been calibrated.
% ----------------------------------------------------------------------------
% crsLiveTrackGetCalibrated
% ================
% This function returns True if the subject has been calibrated and False
% otherwise. 
%
% MATLAB Syntax
% =============
% [isCalibrated, ErrorCode] = crsLiveTrackGetCalibrated(whichEye);
%
%   whichEye - 'leftEye' to get left eye or 'RightEye' to get right eye
%
% Return values
% =============
% isCalibrated - A Boolean (1-by-1 matrix), where 0=False and 1=True.
%
% ----------------------------------------------------------------------------

if nargin~=1,
    error('whichEye must be specified.');
end

if strcmpi(whichEye,'leftEye')
    eye=0;
    disp('Setting calibration parameters for left eye...');
elseif strcmpi(whichEye,'rightEye')
    eye=1;
    disp('Setting calibration parameters for right eye...');
else
    error('ERROR: whichEye parameter must be either ''leftEye'' or ''rightEye''')
end

% Access Toolbox Constants
global CRS;

[isCalibrated, ErrorCode] = crsLiveTrack(CRS.mexGetCalibrated,eye);

if(isCalibrated==0)
    isCalibrated = false; 
else
    isCalibrated = true;
end