function [ calibration, viewDist ] = crsLiveTrackGetCalibration(whichEye)
% CRSLIVETRACKGETCALIBRATION This function gets the gaze calibration of CRS
% LiveTrack.
% ----------------------------------------------------------------------------
%
% MATLAB Syntax
% =============
% [ calibration ] = crsLiveTrackGetCalibration(whichEye)
%
% whichEye - this must be set to either: 'leftEye' or 'RightEye' 
%
% Return values
% =============
% calibration  - a 18 entry array containing the gaze calibration parameters
%
% Example
% =======
% left_eye_calibration = crsLiveTrackGetCalibration('leftEye')
%
% History:
% 09/2017   JT Created  
% 01/2018   JT Added median glint calibration parameters (calibration is 
%           now 18 entries instead of 16) and returning viewDist
%% Access the Toolbox Constants and get the calibration

if strcmpi(whichEye,'leftEye') || strcmpi(whichEye,'left')
    eye=0;
    disp('Retrieving calibration parameters for left eye...');
elseif strcmpi(whichEye,'rightEye') || strcmpi(whichEye,'right')
    eye=1;
    disp('Retrieving calibration parameters for right eye...');
else
    error('ERROR: whichEye parameter must be either: ''leftEye'' or ''rightEye''')
end

% Access Toolbox Constants
global CRS;

% Get the calibration parameters
[ calibration, viewDist ] = crsLiveTrack(CRS.mexGetCalibration, eye);

