function [ err ] = crsLiveTrackSetCalibration(whichEye, calibration, viewDist)
% CRSLIVETRACKSETCALIBRATION This function sets the gaze calibration of CRS
% LiveTrack Toolbox for MATLAB.
% ----------------------------------------------------------------------------
%
% MATLAB Syntax
% =============
% [ err ] = crsLiveTrackSetCalibration(whichEye, calibration, viewDist)
%
% whichEye - this must be set to either: 'leftEye' or 'righteye' 
%
% calibration  - a 18 entry array containing the gaze calibration parameters
%
% viewDist - viewing distance in millimeters
%
% Return values
% =============
% err - An integer where 0 indicates the calibration has been
% successfully set
%
% History:
% 07/2017   JT Created  
% 09/2017   SS Added viewDist
% 01/2018   JT Added median glint calibration parameters (calibration is 
%           now 18 entries instead of 16)

%% Access the Toolbox Constants and set the calilbration

% if median glint is not provided, set to zero
if length(calibration)==16
    calibration = [calibration 0 0];
elseif length(calibration)~=18
    error('Number of calibration parameters not valid!');
end

if strcmpi(whichEye,'leftEye')
    eye=0;
    disp('Setting calibration parameters for left eye...');
elseif strcmpi(whichEye,'rightEye')
    eye=1;
    disp('Setting calibration parameters for right eye...');
else
    error('ERROR: whichEye parameter must be either ''left'' or ''right''')
end

% Access Toolbox Constants
global CRS;

% Set the calibration parameters
err = crsLiveTrack(CRS.mexSetCalibration, eye, calibration, viewDist);

if (err~=0)
    disp('ERROR: LiveTrack calibration not set!');
end


