function [ err ] = crsLiveTrackSetDataFilename(filename)
% CRSLIVETRACKSETDATAFILENAME This function starts 
% recording eyetracking video to file.
% -------------------------------------------------------------------------
%
% MATLAB Syntax
% =============
% [ err ] = crsLiveTrackSetDataFilename(filename)
%
% filename - the filename to record to including the path
%
% Return values
% =============
% err - An integer where 0 indicates the filename was successfully set
%
% Example
% =======
% crsLiveTrackSetDataFilename('C:\tmp\LiveTrack_data.csv')
%
% History:
% 01/2019   RJL Created  
%
%% Access the Toolbox Constants and Set Data Filename

% Access Toolbox Constants
global CRS;

% Start Recording
if IsWin
    newStr = strrep(filename,'\','\\'); % replace single backslash with double backslash
    err = crsLiveTrack(CRS.mexSetDataFilename, newStr);
elseif IsOSX
    newStr = filename;
    err = crsLiveTrack(CRS.mexSetDataFilename, newStr);
end

if (err~=0)
    disp('ERROR: LiveTrack data filename not set!');
end
if (err==0)
    disp(['LiveTrack data filename set:' filename]);
end
