function [ err ] = crsLiveTrackSetResultsTypeCalibrated
% CRSLIVETRACKSETRESULTSTYPECALIBRATED This function tells LiveTrack to send
% calibrated data rather than raw data.
% No input parameters required.
%
% Calibrated data consists of the x, y and z coordinates of the gaze
% vector, where x and y are in the plane of the screen and z is the 
% viewing distance. Units are typically in millimetres but can be
% calibrated to any units. The units will those used for 'targets'
% when calibrating with crsLiveTrackCalibrateDevice.
% The pupil ellipse fit major and minor axis will be scaled according to
% the scalefactor set by crsLiveTrackSetPupilCalibration or if not set,
% then a default calibration will used. You can check the value using the
% function crsLiveTrackGetPupilCalibration.
% -------------------------------------------------------------------------
%
% MATLAB Syntax
% =============
% [ err ] = crsLiveTrackSetResultsTypeCalibrated
%
% Return values
% =============
% err - An integer where 0 indicates the results type has been successfully
% set to calibrated
%
%
% History:
% 07/2017   JT Created  

%%

% Load toolbox constants
global CRS;

% Call to set the streamed results of calibrated type
err = crsLiveTrack(CRS.mexSetResultsType, CRS.calibrated);

if err==0
    disp('Results type set to Calibrated.');
else
    error('ERROR: Could not set results type.');
end

% also check if device is calibrated
% result = crsLiveTrack(CRS.mexCalibrated);
% if result~=0
%     error('ERROR: Results type set to calibrated but device is not yet calibrated.');
% end
