function crsLiveTrackDemoMeasureFixationAccuracy(viewDist)
%CRSLIVETRACKDEMOMEASUREFIXATIONACCURACY  This demo shows how to get eye 
%   tracking data CRS LiveTrack eye trackers and measure the accuracy from 
%   a number of fixations  
%
%   USAGE:
%   crsLiveTrackDemoMeasureFixationAccuracy(viewDist) sets the viewing
%   distance in millimeters (default is 500 mm)
%
% History:
% 06/2017 JT Created

%% User input

% Define default value for the viewing distance in mm
if nargin<1
    viewDist = 500;
end

% Calibration target locations in degrees of visual angle with the origin
% at the centre of the screen (x-positive=right, y-positive=down)
% targetsDeg = [-7 -7;0 -7;7 -7;-7 0;0 0;7 0;-7 7;0 7;7 7];
% targetsDeg = [-10 -10;0 -10;10 -10;-10 0;0 0;10 0;-10 10;0 10;10 10];
targetsDeg = [-5 -5;5 -5;-5 5;5 5];
targetsDeg = repmat(targetsDeg,3,1);


%% Get the data from LiveTrack

% Initialise LiveTrack
crsLiveTrackInit;

% Get the fixation data
[LGaze, RGaze, targets] = crsLiveTrackGetFixationDataCalibrated(viewDist, targetsDeg);

% Close LiveTrack
crsLiveTrackClose;

%% Analyse the data

% convert error to degrees
MMperDeg = tand(1)*viewDist;

clear LGaze2 RGaze2 targets2 Lerror Rerror
[~,IA,IC] = unique(targetsDeg,'rows');
for i=1:length(IA) % for all unique (the 9 fixations)
    I = find(IC==i); 
    for k=1:length(I) % for each repetition of fixation (10)
        LGaze2(i,k,:) = LGaze(I(k),:)/MMperDeg;
        RGaze2(i,k,:) = RGaze(I(k),:)/MMperDeg;
        targets2(i,k,:) = targets(I(k),:)/MMperDeg;
        Lerror(i,k) = sqrt((LGaze2(i,k,1)-targets2(i,k,1))^2+(LGaze2(i,k,2)-targets2(i,k,2))^2);
        Rerror(i,k) = sqrt((RGaze2(i,k,1)-targets2(i,k,1))^2+(RGaze2(i,k,2)-targets2(i,k,2))^2);
    end
end

figure;
hist(Lerror(:))
xlabel('Error [degrees]')
ylabel('Count')
title(['Fixation error for ',num2str(length(IC)),' fixations - Left eye'])

figure;
hist(Rerror(:))
xlabel('Error [degrees]')
ylabel('Count')
title(['Fixation error for ',num2str(length(IC)),' fixations - Right eye'])


figure; hold on;
for i=1:size(targets2,1) % for all unique (the 9 fixations) 
    for k=1:size(targets2,2) % for each repetition of fixation (10)
        plot(targets2(i,k,1), targets2(i,k,2),'k.','MarkerSize',10);
        plot(LGaze2(i,k,1), LGaze2(i,k,2),'r.','MarkerSize',10);
        plot(RGaze2(i,k,1), RGaze2(i,k,2),'g.','MarkerSize',10);
    end
end

set(gca,'YDir','reverse');
xlabel('Horizontal angle (degrees)');ylabel('Vertical angle (deg)');
legend('Target position','Left eye gaze position','Right  eye gaze position')


