function crsLiveTrackDemoShowGazePositionViSaGe
%CRSLIVETRACKDEMOSHOWGAZEPOSITIONVISAGE  This demo shows how to get eye tracking
%   data from CRS LiveTrack eye trackers and plot a dot at the current gaze 
%   postion on the screen using ViSaGe
%
%   The function does not require any input parameters

% History:
% 11/2017 JT Created from crsLiveTrackDemoShowGazePosition


%% User input

% Set the duration of the sample buffer. The dot shown on the screen is
% placed at the average position of the samples in the buffer. Set buffer
% duration to zero to show the dot at the most recent sample (no averaging)
bufferDuration = 30; % duration in mS

% Define the radius of the dot (in screen pixels) 
fixRadOut = 20;

%Define the dot colour
FixRGB  = [0 0 0];

%% Setup LiveTrack

% Initialise LiveTrack
crsLiveTrackInit;

% Start streaming calibrated results
crsLiveTrackSetResultsTypeCalibrated;

% Start buffering data to the library
crsLiveTrackStartTracking;

% Get the sample rate
[ width, height, sampleRate, offsetX, offsetY, ErrorCode ] = crsLiveTrackGetCaptureConfig; %#ok<ASGLU>

% Calculate how many data samples the fixation duration (fixDur) contains
bufferLength = round((bufferDuration/1000)*sampleRate);

% Make sure the buffer has a length of at least 1
if bufferLength<1
    bufferLength = 1;
end

%% Calculate stimulus screen specification

% Set up the VSG
global CRS;
vsgInit;
crsSetSpatialUnits(CRS.PIXELUNIT);
  
% Get the resolution of the stimulus monitor
ResStim = crsGetScreenSizePixels;

% Get screen width and height (in mm)
ScreenSize = crsGetScreenSizeMM;
screenW = ScreenSize(1);

% Calculate pixel size (in mm) assuming square pixels
pixSize = screenW/ResStim(1);

%% Open PTB windows and start collecting data

% Open a full screen window with grey background on stimulus monitor
crsSetDrawPage(1);
crsClearPage(1,CRS.BACKGROUND);
crsSetFixationColour(FixRGB);

% Set default values for parameters used in the screen refresh loop
tgtLocsL=[0 0];
tgtLocsR=[0 0];

% run for 10 seconds
tic;
while toc<10
    
    % Get the most recent samples in the buffer 
    Data = crsLiveTrackGetLatestEyePosition(bufferLength);
    
    % Calculate the gaze location in screeen pixel coordinates and apply 
    % offset, for left and right eye
    tgtLocsL(1) = round((mean(Data.mmPositions(:,1)))/pixSize);
    tgtLocsL(2) = round((mean(Data.mmPositions(:,2)))/pixSize);
    tgtLocsR(1) = round((mean(Data.mmPositionsRight(:,1)))/pixSize);
    tgtLocsR(2) = round((mean(Data.mmPositionsRight(:,2)))/pixSize);
      
    % Draw a dot for each eye on the stimilus monitor 
    if Data.tracked
        crsDrawOval(tgtLocsL,[fixRadOut,fixRadOut]);
    end
    if Data.trackedRight
        crsDrawOval(tgtLocsR,[fixRadOut,fixRadOut]);
    end
    
    % Update the stimulus screen
    crsPresent;

end

% Stop buffering data to the library
crsLiveTrackStopTracking;

% Clear the buffer
crsLiveTrackClearDataBuffer;

% Close LiveTrack
crsLiveTrackClose;