% function crsLiveTrackDemoStreamCalibratedData
% CRSLIVETRACKDEMOSTREAMCALIBRATEDDATA   This demo shows how to get
% calibrated eye tracking data continously from Cambridge Research Systems
% LiveTrack devices
%
% The demo uses the CRS LiveTrack Toolbox for MATLAB to write the lastest
% data to the MATLAB Command Window for 10 seconds.

% History:
% 07/2017 JT Created

% Initialise LiveTrack
crsLiveTrackInit;

% Set LiveTrack to return calibrated data
crsLiveTrackSetResultsTypeCalibrated;

% Start Tracking
crsLiveTrackStartTracking;

% Run a loop writing the data to MATLAB's command window for 10 seconds
tic;
while toc<10
    
    % Wait a bit to reduce the loop speed
    pause(0.1);
    
    % Get the most recent data sample available, then return it in the
    % structure "Data".
    Data = crsLiveTrackGetLatestEyePosition;
    
    % Clear the command window
    clc;
    
    % Display the data in the command window for both eyes
    fprintf('Time stamp: %0.0f\n',Data.timeStamps);
    fprintf([' - Left Eye -  \n',...
        'Gaze position X: %05.1f  Y: %05.1f\n',...
        'Pupil radius major axis: %05.1f\n',...
        'Azimuth: %05.1f\nElevation:  %05.1f\n',...
        'Longitude: %05.1f\nLatitude:  %05.1f\n'],...
        Data.mmPositions(1),Data.mmPositions(2),...
        Data.pupilDiameter,...
        Data.helmholtzPositions(2),Data.helmholtzPositions(1),...
        Data.fickPositions(1),Data.fickPositions(2));
    fprintf([' - Right Eye - \n',...
        'Gaze position X: %05.1f  Y: %05.1f\n',...
        'Pupil radius major axis: %05.1f\n',...
        'Azimuth: %05.1f\nElevation:  %05.1f\n',...
        'Longitude: %05.1f\nLatitude:  %05.1f\n'],...
        Data.mmPositionsRight(1),Data.mmPositionsRight(2),...
        Data.pupilDiameterRight,...
        Data.helmholtzPositionsRight(2),Data.helmholtzPositionsRight(1),...
        Data.fickPositionsRight(1),Data.fickPositionsRight(2));
end


% Stop Tracking
crsLiveTrackStopTracking;

% Close LiveTrack
crsLiveTrackClose;
