% function crsLiveTrackDemoStreamRawData
% CRSLIVETRACKDEMOSTREAMRAWDATA   This demo shows how to get raw eye
% tracking data continously from Cambridge Research Systems LiveTrack
% devices
%
% The demo uses the CRS LiveTrack Toolbox for MATLAB to write the lastest
% data to the MATLAB Command Window for 10 seconds

% History:
% 07/2017 JT Created

% Initialise LiveTrack
crsLiveTrackInit;

% Set LiveTrack to return raw data
crsLiveTrackSetResultsTypeRaw;

% Start Tracking
crsLiveTrackStartTracking;

% Run a loop writing the data to MATLAB's command window for 10 seconds
tic;
while toc<10
    
    % Wait a bit to reduce the loop speed
    pause(0.1);
    
    % Get the most recent data sample available, then return it in the
    % structure "Data".
    Data = crsLiveTrackGetLatestEyePosition;
    
    % Clear the command window
    clc;
    
    % Display the data in the command window for both eyes
    fprintf('Time stamp: %0.0f\n',Data.timeStamps);
    fprintf([' - Left Eye -  \n',...
        'Tracked: %0.0f\n',...
        'Pupil centre position X: %05.1f  Y: %05.1f\n',...
        'Pupil radius major axis: %05.1f\n',...
        'Glint position X: %05.1f Y:  %05.1f\n'],...
        Data.tracked,...
        Data.pupilPositions(1),Data.pupilPositions(2),...
        Data.pupilDiameter,...
        Data.glintPositions(1),Data.glintPositions(2));
    fprintf([' - Right Eye - \n',...
        'Tracked: %0.0f\n',...
        'Pupil centre position X: %05.1f  Y: %05.1f\n',...
        'Pupil radius major axis: %05.1f\n',...
        'Glint position X:. %05.1f Y:  %05.1f\n'],...
        Data.trackedRight,...
        Data.pupilPositionsRight(1),Data.pupilPositionsRight(2),...
        Data.pupilDiameterRight,...
        Data.glintPositionsRight(1),Data.glintPositionsRight(2));
    
end

% Stop Tracking
crsLiveTrackStopTracking;

% Close LiveTrack
crsLiveTrackClose;
